@@ -27,12 +27,11 @@ import inspect
 import logging
 import os
 
-import django
 from django.conf import settings
 from django.conf.urls import include
 from django.conf.urls import url
 from django.core.exceptions import ImproperlyConfigured
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import empty
 from django.utils.functional import SimpleLazyObject
@@ -58,12 +57,7 @@ def _decorate_urlconf(urlpatterns, decorator, *args, **kwargs):
     for pattern in urlpatterns:
         if getattr(pattern, 'callback', None):
             decorated = decorator(pattern.callback, *args, **kwargs)
-            if django.VERSION >= (1, 10):
-                pattern.callback = decorated
-            else:
-                # prior to 1.10 callback was a property and we had
-                # to modify the private attribute behind the property
-                pattern._callback = decorated
+            pattern.callback = decorated
         if getattr(pattern, 'url_patterns', []):
             _decorate_urlconf(pattern.url_patterns, decorator, *args, **kwargs)
 
@@ -89,13 +83,31 @@ def access_cached(func):
     return inner
 
 
+def _wrapped_include(arg):
+    """Convert the old 3-tuple arg for include() into the new format.
+
+    The argument "arg" should be a tuple with 3 elements:
+    (pattern_list, app_namespace, instance_namespace)
+
+    Prior to Django 2.0, django.urls.conf.include() accepts 3-tuple arg
+    (urlconf, namespace, app_name), but it was droppped in Django 2.0.
+    This function is used to convert the older 3-tuple used in horizon code
+    into the new format where namespace needs to be passed as the second arg.
+
+    For more details, see
+    https://docs.djangoproject.com/en/2.0/releases/1.9/#passing-a-3-tuple-or-an-app-name-to-include
+    """
+    pattern_list, app_namespace, instance_namespace = arg
+    return include((pattern_list, app_namespace), namespace=instance_namespace)
+
+
 class NotRegistered(Exception):
     pass
 
 
 @python_2_unicode_compatible
 class HorizonComponent(object):
-    policy_rules = None
+    policy_rules = tuple()
 
     def __init__(self):
         super(HorizonComponent, self).__init__()
@@ -197,7 +209,7 @@ class Registry(object):
             raise ValueError('Only %s classes or subclasses may be '
                              'unregistered.' % self._registerable_class)
 
-        if cls not in self._registry.keys():
+        if cls not in self._registry:
             raise NotRegistered('%s is not registered' % cls)
 
         del self._registry[cls]
@@ -507,7 +519,7 @@ class Dashboard(Registry, HorizonComponent):
                 panel_groups.append((panel_group.slug, panel_group))
 
         # Deal with leftovers (such as add-on registrations)
-        if len(registered):
+        if registered:
             slugs = [panel.slug for panel in registered.values()]
             new_group = PanelGroup(self,
                                    slug="other",
@@ -544,12 +556,13 @@ class Dashboard(Registry, HorizonComponent):
                 continue
             url_slug = panel.slug.replace('.', '/')
             urlpatterns.append(url(r'^%s/' % url_slug,
-                                   include(panel._decorated_urls)))
+                                   _wrapped_include(panel._decorated_urls)))
         # Now the default view, which should come last
         if not default_panel:
             raise NotRegistered('The default panel "%s" is not registered.'
                                 % self.default_panel)
-        urlpatterns.append(url(r'', include(default_panel._decorated_urls)))
+        urlpatterns.append(
+            url(r'', _wrapped_include(default_panel._decorated_urls)))
 
         # Require login if not public.
         if not self.public:
@@ -756,7 +769,7 @@ class Site(Registry, HorizonComponent):
                 dashboard = self._registered(item)
                 dashboards.append(dashboard)
                 registered.pop(dashboard.__class__)
-            if len(registered):
+            if registered:
                 extra = sorted(registered.values())
                 dashboards.extend(extra)
             return dashboards
@@ -772,7 +785,7 @@ class Site(Registry, HorizonComponent):
         """
         if self.default_dashboard:
             return self._registered(self.default_dashboard)
-        elif len(self._registry):
+        elif self._registry:
             return self.get_dashboards()[0]
         else:
             raise NotRegistered("No dashboard modules have been registered.")
@@ -867,7 +880,7 @@ class Site(Registry, HorizonComponent):
         # Compile the dynamic urlconf.
         for dash in self._registry.values():
             urlpatterns.append(url(r'^%s/' % dash.slug,
-                                   include(dash._decorated_urls)))
+                                   _wrapped_include(dash._decorated_urls)))
 
         # Return the three arguments to django.conf.urls.include
         return urlpatterns, self.namespace, self.slug
@@ -1019,7 +1032,8 @@ class HorizonSite(Site):
 
     def __new__(cls, *args, **kwargs):
         if not cls._instance:
-            cls._instance = super(Site, cls).__new__(cls, *args, **kwargs)
+            cls._instance = super(HorizonSite, cls).__new__(cls,
+                                                            *args, **kwargs)
         return cls._instance
 
 
