@@ -85,8 +85,12 @@ horizon.datatables = {
                 .addClass('progress progress-striped active')
                 .appendTo($container);
 
+              // Incomplete progress bar addition
+              $width = $new_row.find('[percent]:first').attr('percent') || "100%";
+
               $(document.createElement('div'))
                 .addClass('progress-bar')
+                .css("width", $width)
                 .appendTo($progress);
 
               // if action/confirm is required, show progress-bar with "?"
@@ -597,6 +601,20 @@ horizon.datatables.add_table_checkboxes = function($parent) {
   });
 };
 
+horizon.datatables.update_header_checkbox = function(table) {
+  var $multi_select_checkbox = table.find('.multi-select-header');
+
+  var $checkboxes = table.find('tbody tr:visible .table-row-multi-select');
+  if ($checkboxes.length == 0) {
+    $multi_select_checkbox.prop('checked', false);
+    $multi_select_checkbox.attr('disabled', true);
+  } else {
+    $multi_select_checkbox.removeAttr('disabled');
+    var not_checked = $checkboxes.not(':checked').length;
+    $multi_select_checkbox.prop('checked', not_checked == 0);
+  }
+};
+
 horizon.datatables.set_table_query_filter = function (parent) {
   horizon.datatables.qs = {};
   $(parent).find('table').each(function (index, elm) {
@@ -634,6 +652,7 @@ horizon.datatables.set_table_query_filter = function (parent) {
           horizon.datatables.update_footer_count(table);
           horizon.datatables.add_no_results_row(table);
           horizon.datatables.fix_row_striping(table);
+          horizon.datatables.update_header_checkbox(table);
         },
         prepareQuery: function (val) {
           return new RegExp(horizon.string.escapeRegex(val), "i");
