@@ -20,13 +20,12 @@ import logging
 import types
 
 from django.conf import settings
-from django.core import urlresolvers
 from django import shortcuts
 from django.template.loader import render_to_string
+from django import urls
 from django.utils.functional import Promise
 from django.utils.http import urlencode
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 import six
 
 from horizon import exceptions
@@ -52,7 +51,7 @@ class BaseActionMetaClass(type):
     parameters for the initializer of the object. The object is then
     initialized clean way. Similar principle is used in DataTableMetaclass.
     """
-    def __new__(mcs, name, bases, attrs):
+    def __new__(cls, name, bases, attrs):
         # Options of action are set as class attributes, loading them.
         options = {}
         if attrs:
@@ -75,7 +74,7 @@ class BaseActionMetaClass(type):
         # instantiating of the specific Action.
         attrs['base_options'] = options
 
-        return type.__new__(mcs, name, bases, attrs)
+        return type.__new__(cls, name, bases, attrs)
 
     def __call__(cls, *args, **kwargs):
         cls.base_options.update(kwargs)
@@ -148,7 +147,6 @@ class BaseAction(html.HTMLElement):
 
         By default this method is a no-op.
         """
-        pass
 
     def get_default_classes(self):
         """Returns a list of the default classes for the action.
@@ -406,10 +404,10 @@ class LinkAction(BaseAction):
         try:
             if datum:
                 obj_id = self.table.get_object_id(datum)
-                return urlresolvers.reverse(self.url, args=(obj_id,))
+                return urls.reverse(self.url, args=(obj_id,))
             else:
-                return urlresolvers.reverse(self.url)
-        except urlresolvers.NoReverseMatch as ex:
+                return urls.reverse(self.url)
+        except urls.NoReverseMatch as ex:
             LOG.info('No reverse found for "%(url)s": %(exception)s',
                      {'url': self.url, 'exception': ex})
             return self.url
@@ -658,6 +656,7 @@ class BatchAction(Action):
     """
 
     help_text = _("This action cannot be undone.")
+    default_message_level = "success"
 
     def __init__(self, **kwargs):
         super(BatchAction, self).__init__(**kwargs)
@@ -688,7 +687,10 @@ class BatchAction(Action):
     def _allowed(self, request, datum=None):
         # Override the default internal action method to prevent batch
         # actions from appearing on tables with no data.
-        if not self.table.data and not datum:
+        # Updating single row of table by ajax prove that there is one
+        # data at least.
+        action = request.GET.get('action')
+        if action != 'row_update' and not self.table.data and not datum:
             return False
         return super(BatchAction, self)._allowed(request, datum)
 
@@ -799,8 +801,7 @@ class BatchAction(Action):
                     'Action %(action)s Failed for %(reason)s', {
                         'action': action_description, 'reason': ex})
 
-        # Begin with success message class, downgrade to info if problems.
-        success_message_level = messages.success
+        success_message_level = getattr(messages, self.default_message_level)
         if action_not_allowed:
             msg = _('You are not allowed to %(action)s: %(objs)s')
             params = {"action":
@@ -964,61 +965,3 @@ class handle_exception_with_detail_message(object):
                 # just to re-raise the exception.
                 raise
         return decorated
-
-
-class Deprecated(type):
-    # TODO(lcastell) Replace class with similar functionality from
-    # oslo_log.versionutils when it's finally added in 11.0
-    def __new__(meta, name, bases, kwargs):
-        cls = super(Deprecated, meta).__new__(meta, name, bases, kwargs)
-        if name != 'UpdateAction':
-            LOG.warning(
-                "WARNING:The UpdateAction class defined in module '%(mod)s' "
-                "is deprecated as of Newton and may be removed in "
-                "Horizon P (12.0). Class '%(name)s' defined at "
-                "module '%(module)s' shall no longer subclass it.",
-                {'mod': UpdateAction.__module__,
-                 'name': name,
-                 'module': kwargs['__module__']})
-        return cls
-
-
-@six.add_metaclass(Deprecated)
-class UpdateAction(object):
-    """**DEPRECATED**: A table action for cell updates by inline editing."""
-
-    name = "update"
-
-    def action(self, request, datum, obj_id, cell_name, new_cell_value):
-        self.update_cell(request, datum, obj_id, cell_name, new_cell_value)
-
-    @staticmethod
-    def action_present(count):
-        return ungettext_lazy(
-            u"Update Item",
-            u"Update Items",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ungettext_lazy(
-            u"Updated Item",
-            u"Updated Items",
-            count
-        )
-
-    def update_cell(self, request, datum, obj_id, cell_name, new_cell_value):
-        """Method for saving data of the cell.
-
-        This method must implements saving logic of the inline edited table
-        cell.
-        """
-
-    def allowed(self, request, datum, cell):
-        """Determine whether updating is allowed for the current request.
-
-        This method is meant to be overridden with more specific checks.
-        Data of the row and of the cell are passed to the method.
-        """
-        return True
