@@ -12,19 +12,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import copy
 from importlib import import_module
 import inspect
 import logging
 
-from django.core import urlresolvers
+from django.conf import settings
 from django import forms
 from django.forms.forms import NON_FIELD_ERRORS
 from django import template
 from django.template.defaultfilters import linebreaks
 from django.template.defaultfilters import safe
 from django.template.defaultfilters import slugify
+from django import urls
 from django.utils.encoding import force_text
+from django.utils import module_loading
 from django.utils.translation import ugettext_lazy as _
 from openstack_auth import policy
 import six
@@ -58,22 +61,21 @@ class WorkflowContext(dict):
 
 
 class ActionMetaclass(forms.forms.DeclarativeFieldsMetaclass):
-    def __new__(mcs, name, bases, attrs):
+    def __new__(cls, name, bases, attrs):
         # Pop Meta for later processing
         opts = attrs.pop("Meta", None)
         # Create our new class
-        cls = super(ActionMetaclass, mcs).__new__(mcs, name, bases, attrs)
+        cls_ = super(ActionMetaclass, cls).__new__(cls, name, bases, attrs)
         # Process options from Meta
-        cls.name = getattr(opts, "name", name)
-        cls.slug = getattr(opts, "slug", slugify(name))
-        cls.permissions = getattr(opts, "permissions", ())
-        cls.policy_rules = getattr(opts, "policy_rules", ())
-        cls.progress_message = getattr(opts,
-                                       "progress_message",
-                                       _("Processing..."))
-        cls.help_text = getattr(opts, "help_text", "")
-        cls.help_text_template = getattr(opts, "help_text_template", None)
-        return cls
+        cls_.name = getattr(opts, "name", name)
+        cls_.slug = getattr(opts, "slug", slugify(name))
+        cls_.permissions = getattr(opts, "permissions", ())
+        cls_.policy_rules = getattr(opts, "policy_rules", ())
+        cls_.progress_message = getattr(opts, "progress_message",
+                                        _("Processing..."))
+        cls_.help_text = getattr(opts, "help_text", "")
+        cls_.help_text_template = getattr(opts, "help_text_template", None)
+        return cls_
 
 
 @six.python_2_unicode_compatible
@@ -479,10 +481,10 @@ class Step(object):
 
 
 class WorkflowMetaclass(type):
-    def __new__(mcs, name, bases, attrs):
-        super(WorkflowMetaclass, mcs).__new__(mcs, name, bases, attrs)
-        attrs["_cls_registry"] = set([])
-        return type.__new__(mcs, name, bases, attrs)
+    def __new__(cls, name, bases, attrs):
+        super(WorkflowMetaclass, cls).__new__(cls, name, bases, attrs)
+        attrs["_cls_registry"] = []
+        return type.__new__(cls, name, bases, attrs)
 
 
 class UpdateMembersStep(Step):
@@ -652,12 +654,15 @@ class Workflow(html.HTMLElement):
         self.entry_point = entry_point
         self.object = None
 
+        self._register_steps_from_config()
+
         # Put together our steps in order. Note that we pre-register
         # non-default steps so that we can identify them and subsequently
         # insert them in order correctly.
-        self._registry = dict([(step_class, step_class(self)) for step_class
-                               in self.__class__._cls_registry
-                               if step_class not in self.default_steps])
+        self._registry = collections.OrderedDict(
+            [(step_class, step_class(self)) for step_class
+             in self.__class__._cls_registry
+             if step_class not in self.default_steps])
         self._gather_steps()
 
         # Determine all the context data we need to end up with.
@@ -670,9 +675,9 @@ class Workflow(html.HTMLElement):
         # registered and ordered.
         self.context = WorkflowContext(self)
         context_seed = context_seed or {}
-        clean_seed = dict([(key, val)
-                           for key, val in context_seed.items()
-                           if key in self.contributions | self.depends_on])
+        clean_seed = dict((key, val)
+                          for key, val in context_seed.items()
+                          if key in self.contributions | self.depends_on)
         self.context_seed = clean_seed
         self.context.update(clean_seed)
 
@@ -698,6 +703,27 @@ class Workflow(html.HTMLElement):
             if step.slug == slug:
                 return step
 
+    def _register_steps_from_config(self):
+        my_name = '.'.join([self.__class__.__module__,
+                            self.__class__.__name__])
+        horizon_config = settings.HORIZON_CONFIG.get('extra_steps', {})
+        extra_steps = horizon_config.get(my_name, [])
+        for step in extra_steps:
+            self._register_step_from_config(step, my_name)
+
+    def _register_step_from_config(self, step_config, my_name):
+        if not isinstance(step_config, str):
+            LOG.error('Extra step definition must be a string '
+                      '(workflow "%s"', my_name)
+            return
+        try:
+            class_ = module_loading.import_string(step_config)
+        except ImportError:
+            LOG.error('Step class "%s" is not found (workflow "%s")',
+                      step_config, my_name)
+            return
+        self.register(class_)
+
     def _gather_steps(self):
         ordered_step_classes = self._order_steps()
         for default_step in self.default_steps:
@@ -775,7 +801,7 @@ class Workflow(html.HTMLElement):
         if step_class in cls._cls_registry:
             return False
         else:
-            cls._cls_registry.add(step_class)
+            cls._cls_registry.append(step_class)
             return True
 
     @classmethod
@@ -783,7 +809,7 @@ class Workflow(html.HTMLElement):
         """Unregisters a :class:`~horizon.workflows.Step` from the workflow."""
         try:
             cls._cls_registry.remove(step_class)
-        except KeyError:
+        except ValueError:
             raise base.NotRegistered('%s is not registered' % cls)
         return cls._unregister(step_class)
 
@@ -858,8 +884,8 @@ class Workflow(html.HTMLElement):
         or a standard HTTP URL.
         """
         try:
-            return urlresolvers.reverse(self.success_url)
-        except urlresolvers.NoReverseMatch:
+            return urls.reverse(self.success_url)
+        except urls.NoReverseMatch:
             return self.success_url
 
     def format_status_message(self, message):
@@ -878,7 +904,7 @@ class Workflow(html.HTMLElement):
 
     def verify_integrity(self):
         provided_keys = self.contributions | set(self.context_seed.keys())
-        if len(self.depends_on - provided_keys):
+        if self.depends_on - provided_keys:
             raise exceptions.NotAvailable(
                 _("The current user has insufficient permission to complete "
                   "the requested task."))
