@@ -27,7 +27,7 @@ INSTALLED_APPS = [
     'openstack_auth.tests'
 ]
 
-MIDDLEWARE_CLASSES = [
+MIDDLEWARE = [
     'openstack_auth.middleware.OpenstackAuthMonkeyPatchMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -74,6 +74,27 @@ TEMPLATES = [
     },
 ]
 
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': False,
+    'handlers': {
+        'null': {
+            'level': 'DEBUG',
+            'class': 'logging.NullHandler',
+        },
+        'test': {
+            'level': 'ERROR',
+            'class': 'logging.StreamHandler',
+        }
+    },
+    'loggers': {
+        'openstack_auth': {
+            'handlers': ['test'],
+            'propagate': False,
+        },
+    }
+}
+
 AUTH_USER_MODEL = 'openstack_auth.User'
 
 LOGGING = {
