@@ -37,8 +37,8 @@ We need the request object to get the user, so we'll slightly modify the
 existing django.contrib.auth.get_user method. To do so we update the
 auth middleware to point to our overridden method.
 
-Calling the "patch_middleware_get_user" method somewhere like our urls.py
-file takes care of hooking it in appropriately.
+Calling "patch_middleware_get_user" is done in our custom middleware at
+"openstack_auth.middleware" to monkeypatch the code in before it is needed.
 """
 
 
@@ -146,6 +146,30 @@ def is_websso_enabled():
     return websso_enabled and keystonev3_plus
 
 
+def is_websso_default_redirect():
+    """Checks if the websso default redirect is available.
+
+    As with websso, this is only supported in Keystone version 3.
+    """
+    websso_default_redirect = getattr(settings,
+                                      'WEBSSO_DEFAULT_REDIRECT', False)
+    keystonev3_plus = (get_keystone_version() >= 3)
+    return websso_default_redirect and keystonev3_plus
+
+
+def get_websso_default_redirect_protocol():
+    return getattr(settings, 'WEBSSO_DEFAULT_REDIRECT_PROTOCOL', None)
+
+
+def get_websso_default_redirect_region():
+    return getattr(settings, 'WEBSSO_DEFAULT_REDIRECT_REGION',
+                   settings.OPENSTACK_KEYSTONE_URL)
+
+
+def get_websso_default_redirect_logout():
+    return getattr(settings, 'WEBSSO_DEFAULT_REDIRECT_LOGOUT', None)
+
+
 def build_absolute_uri(request, relative_url):
     """Ensure absolute_uri are relative to WEBROOT."""
     webroot = getattr(settings, 'WEBROOT', '')
@@ -167,7 +191,8 @@ def get_websso_url(request, auth_url, websso_auth):
     :param request: Django http request object.
     :type request: django.http.HttpRequest
     :param auth_url: Keystone endpoint configured in the horizon setting.
-                     The value is derived from:
+                     If WEBSSO_KEYSTONE_URL is defined, its value will be
+                     used. Otherwise, the value is derived from:
                      - OPENSTACK_KEYSTONE_URL
                      - AVAILABLE_REGIONS
     :type auth_url: string
