@@ -133,9 +133,13 @@ class APIResourceWrapper(object):
     def to_dict(self):
         obj = {}
         for key in self._attrs:
-            obj[key] = getattr(self._apiresource, key, None)
+            obj[key] = getattr(self, key, None)
         return obj
 
+    @property
+    def name_or_id(self):
+        return self.name or '(%s)' % self.id[:13]
+
 
 class APIDictWrapper(object):
     """Simple wrapper for api dictionaries
@@ -208,6 +212,8 @@ class QuotaSet(Sequence):
     use the `get` method to retrieve a specific quota, but otherwise it
     behaves much like a list or tuple, particularly in supporting iteration.
     """
+    ignore_quotas = {}
+
     def __init__(self, apiresource=None):
         self.items = []
         if apiresource:
@@ -217,7 +223,7 @@ class QuotaSet(Sequence):
                 items = apiresource.items()
 
             for k, v in items:
-                if k == 'id':
+                if k == 'id' or k in self.ignore_quotas:
                     continue
                 self[k] = v
 
@@ -252,7 +258,7 @@ class QuotaSet(Sequence):
 
     def get(self, key, default=None):
         match = [quota for quota in self.items if quota.name == key]
-        return match.pop() if len(match) else Quota(key, default)
+        return match.pop() if match else Quota(key, default)
 
     def add(self, other):
         return self.__add__(other)
@@ -311,9 +317,8 @@ def get_url_for_service(service, region, endpoint_type):
                 if endpoint.get('interface') == interface:
                     return endpoint.get('url')
         except (IndexError, KeyError):
-            """it could be that the current endpoint just doesn't match the
-            type, continue trying the next one
-            """
+            # it could be that the current endpoint just doesn't match the
+            # type, continue trying the next one
             pass
     return None
 
