@@ -44,13 +44,14 @@ LOG = logging.getLogger(__name__)
 VERSIONS = base.APIVersionManager("image", preferred_version=2)
 
 try:
+    # pylint: disable=ungrouped-imports
     from glanceclient.v2 import client as glance_client_v2
     VERSIONS.load_supported_version(2, {"client": glance_client_v2,
                                         "version": 2})
 except ImportError:
     pass
-
 try:
+    # pylint: disable=ungrouped-imports
     from glanceclient.v1 import client as glance_client_v1
     VERSIONS.load_supported_version(1, {"client": glance_client_v1,
                                         "version": 1})
@@ -78,9 +79,6 @@ class Image(base.APIResourceWrapper):
     _ext_attrs = {"file", "locations", "schema", "tags", "virtual_size",
                   "kernel_id", "ramdisk_id", "image_url"}
 
-    def __init__(self, apiresource):
-        super(Image, self).__init__(apiresource)
-
     def __getattribute__(self, attr):
         # Because Glance v2 treats custom properties as normal
         # attributes, we need to be more flexible than the resource
@@ -493,7 +491,8 @@ def create_image_metadata(data):
     _handle_unknown_properties(data, properties)
 
     if ('visibility' in data and
-            data['visibility'] not in ['public', 'private', 'shared']):
+            data['visibility'] not in ['public', 'private', 'community',
+                                       'shared']):
         raise KeyError('invalid visibility option: %s' % data['visibility'])
     _normalize_is_public_filter(data)
 
@@ -629,10 +628,7 @@ class Namespace(BaseGlanceMetadefAPIResourceWrapper):
 
     @property
     def public(self):
-        if getattr(self._apiresource, 'visibility') == 'public':
-            return True
-        else:
-            return False
+        return getattr(self._apiresource, 'visibility') == 'public'
 
 
 def filter_properties_target(namespaces_iter,
