@@ -67,7 +67,8 @@ class Image(generic.View):
         :param min_disk: (optional) the minimum disk size
              for the image to boot with
         :param min_ram: (optional) the minimum ram for the image to boot with
-        :param visibility: (required) takes 'public', 'shared', and 'private'
+        :param visibility: (required) takes 'public', 'shared', 'private' and
+             'community'
         :param protected: (required) true if the image is protected
 
         Any parameters not listed above will be assigned as custom properties
@@ -105,6 +106,9 @@ class ImageProperties(generic.View):
 
         This method returns HTTP 204 (no content) on success.
         """
+        if "os_hidden" in request.DATA['updated']:
+            request.DATA['updated']['os_hidden'] = (
+                request.DATA['updated']['os_hidden'] == "true")
         api.glance.image_update_properties(
             request, image_id, request.DATA.get('removed'),
             **request.DATA['updated']
@@ -199,7 +203,8 @@ class Images(generic.View):
         :param min_disk: (optional) the minimum disk size
              for the image to boot with
         :param min_ram: (optional) the minimum ram for the image to boot with
-        :param visibility: (required) takes 'public', 'private', and 'shared'
+        :param visibility: (required) takes 'public', 'private', 'shared', and
+             'community'
         :param protected: (required) true if the image is protected
         :param import_data: (optional) true to copy the image data
             to the image service or use it from the current location
