@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.conf import settings
 from django.template.defaultfilters import title
 from django.utils.translation import ugettext_lazy as _
 
@@ -38,7 +39,6 @@ class DownloadEC2(tables.LinkAction):
     verbose_name_plural = _("EC2 Credentials")
     icon = "download"
     url = "horizon:project:api_access:ec2"
-    policy_rules = (("compute", "os_compute_api:os-certificates:create"),)
 
     def allowed(self, request, datum=None):
         return api.base.is_service_enabled(request, 'ec2')
@@ -51,16 +51,28 @@ class DownloadCloudsYaml(tables.LinkAction):
     icon = "download"
     url = "horizon:project:api_access:clouds.yaml"
 
+    def allowed(self, request, datum=None):
+        return settings.SHOW_OPENSTACK_CLOUDS_YAML
+
 
 class DownloadOpenRC(tables.LinkAction):
     name = "download_openrc"
-    verbose_name = _("OpenStack RC File (Identity API v3)")
-    verbose_name_plural = _("OpenStack RC File (Identity API v3)")
+    verbose_name = _("OpenStack RC File")
+    verbose_name_plural = _("OpenStack RC File")
     icon = "download"
     url = "horizon:project:api_access:openrc"
 
+    def __init__(self, attrs=None, **kwargs):
+        super(DownloadOpenRC, self).__init__(attrs, **kwargs)
+        # When keystone v2 RC file is enabled, we need to show
+        # the version information of keystone API.
+        # Note that we don't need to care verbose_name_plural here.
+        if getattr(settings, 'SHOW_KEYSTONE_V2_RC', False):
+            self.verbose_name = _("OpenStack RC File (Identity API v3)")
+
     def allowed(self, request, datum=None):
-        return utils.get_keystone_version() >= 3
+        return (settings.SHOW_OPENRC_FILE and
+                utils.get_keystone_version() >= 3)
 
 
 class DownloadOpenRCv2(tables.LinkAction):
@@ -70,6 +82,9 @@ class DownloadOpenRCv2(tables.LinkAction):
     icon = "download"
     url = "horizon:project:api_access:openrcv2"
 
+    def allowed(self, request, datum=None):
+        return settings.SHOW_KEYSTONE_V2_RC
+
 
 class ViewCredentials(tables.LinkAction):
     name = "view_credentials"
