@@ -12,15 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from mox3.mox import IsA
 import six
 import yaml
 
-from django.core.urlresolvers import reverse
-from django.http import HttpRequest
 from django import template
 from django.template import loader
 from django.test.utils import override_settings
+from django.urls import reverse
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
@@ -36,23 +34,22 @@ RECREATE_CREDS_URL = reverse(API_URL + ":recreate_credentials")
 
 
 class APIAccessTests(test.TestCase):
+    @test.create_mocks({api.keystone: ('create_ec2_credentials',
+                                       'list_ec2_credentials')})
     def test_ec2_download_view(self):
         creds = self.ec2.first()
-
-        self.mox.StubOutWithMock(api.keystone, "list_ec2_credentials")
-        self.mox.StubOutWithMock(api.keystone, "create_ec2_credentials")
-
-        api.keystone.list_ec2_credentials(IsA(HttpRequest), self.user.id) \
-                    .AndReturn([])
-        api.keystone.create_ec2_credentials(IsA(HttpRequest),
-                                            self.user.id,
-                                            self.tenant.id).AndReturn(creds)
-        self.mox.ReplayAll()
+        self.mock_list_ec2_credentials.return_value = []
+        self.mock_create_ec2_credentials.return_value = creds
 
         res = self.client.get(EC2_URL)
         self.assertEqual(res.status_code, 200)
         self.assertEqual(res['content-type'], 'application/zip')
 
+        self.mock_list_ec2_credentials.assert_called_once_with(
+            test.IsHttpRequest(), self.user.id)
+        self.mock_create_ec2_credentials.assert_called_once_with(
+            test.IsHttpRequest(), self.user.id, self.tenant.id)
+
     def test_openrcv2_credentials(self):
         res = self.client.get(OPENRCV2_URL)
         self.assertEqual(res.status_code, 200)
@@ -81,42 +78,32 @@ class APIAccessTests(test.TestCase):
         self.assertIn(p_id.encode('utf-8'), res.content)
         self.assertIn(domain.encode('utf-8'), res.content)
 
-    @test.create_stubs({api.keystone: ("list_ec2_credentials",)})
+    @test.create_mocks({api.keystone: ('list_ec2_credentials',)})
     def test_credential_api(self):
         certs = self.ec2.list()
-        api.keystone.list_ec2_credentials(IsA(HttpRequest), self.user.id) \
-            .AndReturn(certs)
-
-        self.mox.ReplayAll()
+        self.mock_list_ec2_credentials.return_value = certs
 
         res = self.client.get(CREDS_URL)
+
         self.assertEqual(res.status_code, 200)
         credentials = 'project/api_access/credentials.html'
         self.assertTemplateUsed(res, credentials)
         self.assertEqual(self.user.id, res.context['openrc_creds']['user'].id)
         self.assertEqual(certs[0].access,
                          res.context['ec2_creds']['ec2_access_key'])
+        self.mock_list_ec2_credentials.assert_called_once_with(
+            test.IsHttpRequest(), self.user.id)
 
-    @test.create_stubs({api.keystone: ("list_ec2_credentials",
-                                       "create_ec2_credentials",
-                                       "delete_user_ec2_credentials",)})
+    @test.create_mocks({api.keystone: ('create_ec2_credentials',
+                                       'list_ec2_credentials',
+                                       'delete_user_ec2_credentials')})
     def _test_recreate_user_credentials(self, exists_credentials=True):
         old_creds = self.ec2.list() if exists_credentials else []
         new_creds = self.ec2.first()
-        api.keystone.list_ec2_credentials(
-            IsA(HttpRequest),
-            self.user.id).AndReturn(old_creds)
+        self.mock_list_ec2_credentials.return_value = old_creds
         if exists_credentials:
-            api.keystone.delete_user_ec2_credentials(
-                IsA(HttpRequest),
-                self.user.id,
-                old_creds[0].access).AndReturn([])
-        api.keystone.create_ec2_credentials(
-            IsA(HttpRequest),
-            self.user.id,
-            self.tenant.id).AndReturn(new_creds)
-
-        self.mox.ReplayAll()
+            self.mock_delete_user_ec2_credentials.return_value = []
+        self.mock_create_ec2_credentials.return_value = new_creds
 
         res_get = self.client.get(RECREATE_CREDS_URL)
         self.assertEqual(res_get.status_code, 200)
@@ -128,6 +115,16 @@ class APIAccessTests(test.TestCase):
         self.assertNoFormErrors(res_post)
         self.assertRedirectsNoFollow(res_post, INDEX_URL)
 
+        self.mock_list_ec2_credentials.assert_called_once_with(
+            test.IsHttpRequest(), self.user.id)
+        if exists_credentials:
+            self.mock_delete_user_ec2_credentials.assert_called_once_with(
+                test.IsHttpRequest(), self.user.id, old_creds[0].access)
+        else:
+            self.mock_delete_user_ec2_credentials.assert_not_called()
+        self.mock_create_ec2_credentials.assert_called_once_with(
+            test.IsHttpRequest(), self.user.id, self.tenant.id)
+
     def test_recreate_user_credentials(self):
         self._test_recreate_user_credentials()
 
@@ -285,7 +282,7 @@ class TemplateRenderTest(test.TestCase):
             "auth_url": "http://example.com",
             "tenant_name": "Tenant",
             "region": "Colorado"}
-        out = yaml.load(loader.render_to_string(
+        out = yaml.safe_load(loader.render_to_string(
             'project/api_access/clouds.yaml.template',
             context,
             template.Context(context)))
@@ -306,7 +303,7 @@ class TemplateRenderTest(test.TestCase):
             "tenant_id": "some-cool-id",
             "auth_url": "http://example.com",
             "tenant_name": "Tenant"}
-        out = yaml.load(loader.render_to_string(
+        out = yaml.safe_load(loader.render_to_string(
             'project/api_access/clouds.yaml.template',
             context,
             template.Context(context)))
@@ -329,7 +326,7 @@ class TemplateRenderTest(test.TestCase):
             "auth_url": "http://example.com",
             "tenant_name": "Tenant",
             "regions": regions}
-        out = yaml.load(loader.render_to_string(
+        out = yaml.safe_load(loader.render_to_string(
             'project/api_access/clouds.yaml.template',
             context,
             template.Context(context)))
@@ -354,7 +351,7 @@ class TemplateRenderTest(test.TestCase):
             "auth_url": "http://example.com",
             "tenant_name": "Tenant",
             "regions": regions}
-        out = yaml.load(loader.render_to_string(
+        out = yaml.safe_load(loader.render_to_string(
             'project/api_access/clouds.yaml.template',
             context,
             template.Context(context)))
