@@ -22,11 +22,9 @@ from socket import timeout as socket_timeout
 import tempfile
 import unittest
 
-from django import http
 from django.urls import reverse
 
 import mock
-from mox3.mox import IsA
 import six
 
 from horizon import exceptions
@@ -61,7 +59,7 @@ class ImagesAndSnapshotsTests(BaseImagesTestCase):
         images_table = res.context['images_table']
         images = images_table.data
 
-        self.assertEqual(len(images), 9)
+        self.assertEqual(len(images), 10)
         row_actions = images_table.get_row_actions(images[0])
         self.assertEqual(len(row_actions), 5)
         row_actions = images_table.get_row_actions(images[1])
@@ -113,7 +111,7 @@ class ImagesAndSnapshotsTests(BaseImagesTestCase):
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         self.assertIn('images_table', res.context)
         snaps = res.context['images_table']
-        self.assertEqual(len(snaps.get_rows()), 3)
+        self.assertEqual(len(snaps.get_rows()), 4)
 
         row_actions = snaps.get_row_actions(snaps.data[0])
 
@@ -157,9 +155,13 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         shared_images = [image for image in self.imagesV2.list()
                          if (image.status == 'active' and
                              image.visibility == 'shared')]
+        community_images = [image for image in self.imagesV2.list()
+                            if (image.status == 'active' and
+                                image.visibility == 'community')]
         self.mock_image_list.side_effect = [
             [public_images, False, False],
             [private_images, False, False],
+            [community_images, False, False],
             [shared_images, False, False]
         ]
 
@@ -169,6 +171,8 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
             mock.call(test.IsHttpRequest(),
                       filters={'property-owner_id': self.tenant.id,
                                'status': 'active'}),
+            mock.call(test.IsHttpRequest(),
+                      filters={'visibility': 'community', 'status': 'active'}),
             mock.call(test.IsHttpRequest(),
                       filters={'visibility': 'shared', 'status': 'active'})
         ]
@@ -188,6 +192,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         private_images = [image for image in self.images.list()
                           if (image.status == 'active' and
                               not image.is_public)]
+        community_images = [image for image in self.imagesV2.list()
+                            if (image.status == 'active' and
+                                image.visibility == 'community')]
         shared_images = [image for image in self.imagesV2.list()
                          if (image.status == 'active' and
                              image.visibility == 'shared')]
@@ -195,6 +202,7 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.mock_image_list.side_effect = [
             [public_images, False, False],
             [private_images, False, False],
+            [community_images, False, False],
             [shared_images, False, False],
             [private_images, False, False]
         ]
@@ -205,6 +213,8 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
             mock.call(test.IsHttpRequest(),
                       filters={'property-owner_id': self.tenant.id,
                                'status': 'active'}),
+            mock.call(test.IsHttpRequest(),
+                      filters={'visibility': 'community', 'status': 'active'}),
             mock.call(test.IsHttpRequest(),
                       filters={'visibility': 'shared', 'status': 'active'}),
             mock.call(test.IsHttpRequest(),
@@ -227,6 +237,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.assertEqual(
             len(private_images),
             len(images_cache['images_by_project'][self.tenant.id]))
+        self.assertEqual(
+            len(community_images),
+            len(images_cache['community_images']))
         self.assertEqual(
             len(shared_images),
             len(images_cache['shared_images']))
@@ -254,6 +267,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         private_images = [image for image in self.images.list()
                           if (image.status == 'active' and
                               not image.is_public)]
+        community_images = [image for image in self.imagesV2.list()
+                            if (image.status == 'active' and
+                                image.visibility == 'community')]
         shared_images = [image for image in self.imagesV2.list()
                          if (image.status == 'active' and
                              image.visibility == 'shared')]
@@ -261,7 +277,8 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.mock_image_list.side_effect = [
             self.exceptions.glance,
             [private_images, False, False],
-            [shared_images, False, False],
+            [community_images, False, False],
+            [shared_images, False, False]
         ]
 
         images_cache = {}
@@ -272,6 +289,8 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
                       filters={'is_public': True, 'status': 'active'}),
             mock.call(test.IsHttpRequest(),
                       filters={'status': 'active', 'property-owner_id': '1'}),
+            mock.call(test.IsHttpRequest(),
+                      filters={'visibility': 'community', 'status': 'active'}),
             mock.call(test.IsHttpRequest(),
                       filters={'visibility': 'shared', 'status': 'active'})
         ]
@@ -288,6 +307,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.assertEqual(
             len(private_images),
             len(images_cache['images_by_project'][self.tenant.id]))
+        self.assertEqual(
+            len(community_images),
+            len(images_cache['community_images']))
         self.assertEqual(
             len(shared_images),
             len(images_cache['shared_images']))
@@ -299,6 +321,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         private_images = [image for image in self.images.list()
                           if (image.status == 'active' and
                               not image.is_public)]
+        community_images = [image for image in self.imagesV2.list()
+                            if (image.status == 'active' and
+                                image.visibility == 'community')]
         shared_images = [image for image in self.imagesV2.list()
                          if (image.status == 'active' and
                              image.visibility == 'shared')]
@@ -306,6 +331,7 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.mock_image_list.side_effect = [
             [public_images, False, False],
             self.exceptions.glance,
+            [community_images, False, False],
             [shared_images, False, False],
             [private_images, False, False]
         ]
@@ -319,6 +345,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
             len(public_images),
             len(images_cache['public_images']))
         self.assertFalse(len(images_cache['images_by_project']))
+        self.assertEqual(
+            len(community_images),
+            len(images_cache['community_images']))
         self.assertEqual(
             len(shared_images),
             len(images_cache['shared_images']))
@@ -336,6 +365,9 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
         self.assertEqual(
             len(private_images),
             len(images_cache['images_by_project'][self.tenant.id]))
+        self.assertEqual(
+            len(community_images),
+            len(images_cache['community_images']))
         self.assertEqual(
             len(shared_images),
             len(images_cache['shared_images']))
@@ -345,6 +377,8 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
                       filters={'status': 'active', 'is_public': True}),
             mock.call(test.IsHttpRequest(),
                       filters={'status': 'active', 'property-owner_id': '1'}),
+            mock.call(test.IsHttpRequest(),
+                      filters={'status': 'active', 'visibility': 'community'}),
             mock.call(test.IsHttpRequest(),
                       filters={'status': 'active', 'visibility': 'shared'}),
             mock.call(test.IsHttpRequest(),
@@ -357,22 +391,11 @@ class ImagesAndSnapshotsUtilsTests(BaseImagesTestCase):
 
 
 class SeleniumTests(test.SeleniumTestCase):
-    @test.create_stubs({api.glance: ('image_list_detailed',)})
+    @test.create_mocks({api.glance: ('image_list_detailed',)})
     def test_modal_create_image_from_url(self):
         driver = self.selenium
         images = self.images.list()
-        api.glance.image_list_detailed(IsA(http.HttpRequest),
-                                       marker=None).AndReturn([images,
-                                                               False, False])
-        filters = {'disk_format': 'aki'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        filters = {'disk_format': 'ari'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        self.mox.ReplayAll()
+        self.mock_image_list_detailed.return_value = [images, False, False]
 
         driver.get("%s%s" % (self.live_server_url, INDEX_URL))
 
@@ -390,24 +413,21 @@ class SeleniumTests(test.SeleniumTestCase):
         self.assertIn("ISO", body.text,
                       "ISO should be selected when the extension is *.iso")
 
+        self.assertEqual(3, self.mock_image_list_detailed.call_count)
+        self.mock_image_list_detailed.assert_has_calls([
+            mock.call(test.IsHttpRequest(), marker=None, paginate=True,
+                      reversed_order=False, sort_dir='asc', sort_key='name'),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'aki'}),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'ari'}),
+        ])
+
     @unittest.skipIf(os.environ.get('SELENIUM_PHANTOMJS'),
                      "PhantomJS cannot test file upload widgets.")
-    @test.create_stubs({api.glance: ('image_list_detailed',)})
+    @test.create_mocks({api.glance: ('image_list_detailed',)})
     def test_modal_create_image_from_file(self):
         driver = self.selenium
         images = self.images.list()
-        api.glance.image_list_detailed(IsA(http.HttpRequest),
-                                       marker=None).AndReturn([images,
-                                                               False, False])
-        filters = {'disk_format': 'aki'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        filters = {'disk_format': 'ari'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        self.mox.ReplayAll()
+        self.mock_image_list_detailed.return_value = [images, False, False]
 
         driver.get("%s%s" % (self.live_server_url, INDEX_URL))
 
@@ -426,18 +446,19 @@ class SeleniumTests(test.SeleniumTestCase):
         self.assertIn("ISO", body.text,
                       "ISO should be selected when the extension is *.iso")
 
-    @test.create_stubs({api.glance: ('image_list_detailed',)})
+        self.assertEqual(3, self.mock_image_list_detailed.call_count)
+        self.mock_image_list_detailed.assert_has_calls([
+            mock.call(test.IsHttpRequest(), marker=None, paginate=True,
+                      reversed_order=False, sort_dir='asc', sort_key='name'),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'aki'}),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'ari'}),
+        ])
+
+    @test.create_mocks({api.glance: ('image_list_detailed',)})
     def test_create_image_from_url(self):
         driver = self.selenium
-        filters = {'disk_format': 'aki'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        filters = {'disk_format': 'ari'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        self.mox.ReplayAll()
+        self.mock_image_list_detailed.return_value = [self.images.list(),
+                                                      False, False]
 
         driver.get("%s%s" % (self.live_server_url, CREATE_URL))
         wait = self.ui.WebDriverWait(driver, 10,
@@ -453,20 +474,19 @@ class SeleniumTests(test.SeleniumTestCase):
         self.assertIn("ISO", body.text,
                       "ISO should be selected when the extension is *.iso")
 
+        self.assertEqual(2, self.mock_image_list_detailed.call_count)
+        self.mock_image_list_detailed.assert_has_calls([
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'aki'}),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'ari'}),
+        ])
+
     @unittest.skipIf(os.environ.get('SELENIUM_PHANTOMJS'),
                      "PhantomJS cannot test file upload widgets.")
-    @test.create_stubs({api.glance: ('image_list_detailed',)})
+    @test.create_mocks({api.glance: ('image_list_detailed',)})
     def test_create_image_from_file(self):
         driver = self.selenium
-        filters = {'disk_format': 'aki'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        filters = {'disk_format': 'ari'}
-        api.glance.image_list_detailed(
-            IsA(http.HttpRequest), filters=filters).AndReturn(
-            [self.images.list(), False, False])
-        self.mox.ReplayAll()
+        self.mock_image_list_detailed.return_value = [self.images.list(),
+                                                      False, False]
 
         driver.get("%s%s" % (self.live_server_url, CREATE_URL))
         wait = self.ui.WebDriverWait(driver, 10,
@@ -482,3 +502,9 @@ class SeleniumTests(test.SeleniumTestCase):
 
         self.assertIn("ISO", body.text,
                       "ISO should be selected when the extension is *.iso")
+
+        self.assertEqual(2, self.mock_image_list_detailed.call_count)
+        self.mock_image_list_detailed.assert_has_calls([
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'aki'}),
+            mock.call(test.IsHttpRequest(), filters={'disk_format': 'ari'}),
+        ])
