@@ -34,6 +34,11 @@ class AuditTable(tables.DataTable):
         ("reboot", pgettext_lazy("Action log of an instance", u"Reboot")),
         ("stop", pgettext_lazy("Action log of an instance", u"Stop")),
         ("start", pgettext_lazy("Action log of an instance", u"Start")),
+        ("shelve", pgettext_lazy("Action log of an instance", u"Shelve")),
+        ("unshelve", pgettext_lazy("Action log of an instance", u"Unshelve")),
+        ("migrate", pgettext_lazy("Action log of an instance", u"Migrate")),
+        ("rescue", pgettext_lazy("Action log of an instance", u"Rescue")),
+        ("unrescue", pgettext_lazy("Action log of an instance", u"Unrescue")),
     )
 
     request_id = tables.Column('request_id',
