@@ -35,8 +35,7 @@ class OverviewTab(tabs.Tab):
                      "_detail_overview.html")
 
     def get_context_data(self, request):
-        return {"instance": self.tab_group.kwargs['instance'],
-                "is_superuser": request.user.is_superuser}
+        return {"instance": self.tab_group.kwargs['instance']}
 
 
 class InterfacesTab(tabs.TableTab):
