@@ -12,25 +12,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
-from horizon import forms
 from horizon import tabs
 from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
 
-from openstack_dashboard.dashboards.project.networks.ports \
-    import forms as project_forms
 from openstack_dashboard.dashboards.project.networks.ports \
     import tables as project_tables
 from openstack_dashboard.dashboards.project.networks.ports \
     import tabs as project_tabs
 from openstack_dashboard.dashboards.project.networks.ports \
     import workflows as project_workflows
+from openstack_dashboard.utils import futurist_utils
 
 
 STATE_DICT = dict(project_tables.DISPLAY_CHOICES)
@@ -38,19 +36,9 @@ STATUS_DICT = dict(project_tables.STATUS_DISPLAY_CHOICES)
 VNIC_TYPE_DICT = dict(api.neutron.VNIC_TYPES)
 
 
-class CreateView(forms.ModalFormView):
-    form_class = project_forms.CreatePort
-    form_id = "create_port_form"
-    modal_header = _("Create Port")
-    submit_label = _("Create Port")
-    submit_url = "horizon:project:networks:addport"
-    page_title = _("Create Port")
-    template_name = 'project/networks/ports/create.html'
-    url = 'horizon:project:networks:detail'
-
-    def get_success_url(self):
-        return reverse(self.url,
-                       args=(self.kwargs['network_id'],))
+class CreateView(workflows.WorkflowView):
+    workflow_class = project_workflows.CreatePort
+    failure_url = 'horizon:project:networks:detail'
 
     @memoized.memoized_method
     def get_network(self):
@@ -58,23 +46,16 @@ class CreateView(forms.ModalFormView):
             network_id = self.kwargs["network_id"]
             return api.neutron.network_get(self.request, network_id)
         except Exception:
-            redirect = reverse(self.url,
+            redirect = reverse(self.failure_url,
                                args=(self.kwargs['network_id'],))
             msg = _("Unable to retrieve network.")
             exceptions.handle(self.request, msg, redirect=redirect)
 
-    def get_context_data(self, **kwargs):
-        context = super(CreateView, self).get_context_data(**kwargs)
-        context['network'] = self.get_network()
-        args = (self.kwargs['network_id'],)
-        context['submit_url'] = reverse(self.submit_url, args=args)
-        context['cancel_url'] = reverse(self.url, args=args)
-        return context
-
     def get_initial(self):
         network = self.get_network()
         return {"network_id": self.kwargs['network_id'],
-                "network_name": network.name}
+                "network_name": network.name,
+                "target_tenant_id": network.tenant_id}
 
 
 class DetailView(tabs.TabbedTableView):
@@ -101,49 +82,53 @@ class DetailView(tabs.TabbedTableView):
             msg = _('Unable to retrieve port details.')
             exceptions.handle(self.request, msg, redirect=redirect)
 
-        if (api.neutron.is_extension_supported(self.request, 'mac-learning')
-                and not hasattr(port, 'mac_state')):
+        if (api.neutron.is_extension_supported(self.request,
+                                               'mac-learning') and
+                not hasattr(port, 'mac_state')):
             port.mac_state = api.neutron.OFF_STATE
 
         return port
 
-    @memoized.memoized_method
-    def get_network(self, network_id):
-        try:
-            network = api.neutron.network_get(self.request, network_id)
-        except Exception:
-            network = {}
-            msg = _('Unable to retrieve network details.')
-            exceptions.handle(self.request, msg)
-
-        return network
-
-    @memoized.memoized_method
-    def get_security_groups(self, sg_ids):
-        # Avoid extra API calls if no security group is associated.
-        if not sg_ids:
-            return []
-        try:
-            security_groups = api.neutron.security_group_list(self.request,
-                                                              id=sg_ids)
-        except Exception:
-            security_groups = []
-            msg = _("Unable to retrieve security groups for the port.")
-            exceptions.handle(self.request, msg)
-        return security_groups
-
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
         port = self.get_data()
         network_url = "horizon:project:networks:detail"
         subnet_url = "horizon:project:networks:subnets:detail"
-        network = self.get_network(port.network_id)
+
+        @memoized.memoized_method
+        def get_network(network_id):
+            try:
+                network = api.neutron.network_get(self.request, network_id)
+            except Exception:
+                network = {}
+                msg = _('Unable to retrieve network details.')
+                exceptions.handle(self.request, msg)
+
+            return network
+
+        @memoized.memoized_method
+        def get_security_groups(sg_ids):
+            # Avoid extra API calls if no security group is associated.
+            if not sg_ids:
+                return []
+            try:
+                security_groups = api.neutron.security_group_list(self.request,
+                                                                  id=sg_ids)
+            except Exception:
+                security_groups = []
+                msg = _("Unable to retrieve security groups for the port.")
+                exceptions.handle(self.request, msg)
+            return security_groups
+
+        results = futurist_utils.call_functions_parallel(
+            (get_network, [port.network_id]),
+            (get_security_groups, [tuple(port.security_groups)]))
+        network, port.security_groups = results
+
         port.network_name = network.get('name')
         port.network_url = reverse(network_url, args=[port.network_id])
         for ip in port.fixed_ips:
             ip['subnet_url'] = reverse(subnet_url, args=[ip['subnet_id']])
-        port.security_groups = self.get_security_groups(
-            tuple(port.security_groups))
         table = project_tables.PortsTable(self.request,
                                           network_id=port.network_id)
         # TODO(robcresswell) Add URL for "Ports" crumb after bug/1416838
