@@ -203,6 +203,7 @@
         source: [],
         create_volume_default: true,
         // REQUIRED for JS logic
+        hide_create_volume: false,
         vol_create: false,
         // May be null
         vol_device_name: 'vda',
@@ -297,6 +298,9 @@
         // Append "_default" to distinguish from the 'vol_create' item
         model.newInstanceSpec.create_volume_default = defaults.create_volume;
       }
+      if ('hide_create_volume' in defaults) {
+        model.newInstanceSpec.hide_create_volume = defaults.hide_create_volume;
+      }
     }
 
     /**
@@ -328,8 +332,10 @@
 
     function successMessage() {
       var numberInstances = model.newInstanceSpec.instance_count;
-      var message = ngettext('%s instance launched.', '%s instances launched.', numberInstances);
-      toast.add('success', interpolate(message, [numberInstances]));
+      var message = ngettext('Scheduled creation of %s instance.',
+                             'Scheduled creation of %s instances.',
+                             numberInstances);
+      toast.add('info', interpolate(message, [numberInstances]));
     }
 
     function cleanNullProperties(finalSpec) {
@@ -559,14 +565,11 @@
 
       if (enabledImage || enabledSnapshot) {
         var filter = {status: 'active', sort_key: 'name', sort_dir: 'asc'};
-        return glanceAPI.getImages(filter).then(function getEnabledImages(data) {
-          if (enabledImage) {
-            onGetImages(data);
+        glanceAPI.getImages(filter).then(
+          function(data) {
+            onGetImageSources(data, enabledImage, enabledSnapshot);
           }
-          if (enabledSnapshot) {
-            onGetSnapshots(data);
-          }
-        });
+        );
       }
     }
 
@@ -649,27 +652,50 @@
       return bootSourceTypes.NON_BOOTABLE_IMAGE_TYPES.indexOf(image.container_format) < 0;
     }
 
-    function onGetImages(data) {
-      model.images.length = 0;
-      push.apply(model.images, data.data.items.filter(function (image) {
-        return isBootableImageType(image) &&
-          (!image.properties || image.properties.image_type !== 'snapshot');
-      }));
-      addAllowedBootSource(model.images, bootSourceTypes.IMAGE, gettext('Image'));
+    function getImageType(image) {
+      if (image === null || !angular.isDefined(image.properties) ||
+          !(angular.isDefined(image.properties.image_type) ||
+            angular.isDefined(image.properties.block_device_mapping))) {
+        return 'image';
+      }
+      return image.properties.image_type ||
+             angular.fromJson(image.properties.block_device_mapping)[0].source_type ||
+             'image';
     }
 
-    function onGetSnapshots(data) {
-      model.imageSnapshots.length = 0;
-      push.apply(model.imageSnapshots, data.data.items.filter(function (image) {
-        return isBootableImageType(image) &&
-          (image.properties && image.properties.image_type === 'snapshot');
-      }));
+    function isValidImage(image) {
+      return isBootableImageType(image) &&
+             (!image.properties || image.properties.image_type !== 'snapshot');
+    }
 
-      addAllowedBootSource(
-        model.imageSnapshots,
-        bootSourceTypes.INSTANCE_SNAPSHOT,
-        gettext('Instance Snapshot')
-      );
+    function isValidSnapshot(image) {
+      return getImageType(image) === 'snapshot' && isBootableImageType(image);
+    }
+
+    function onGetImageSources(data, enabledImage, enabledSnapshot) {
+      model.imageSnapshots.length = 0;
+      model.images.length = 0;
+
+      angular.forEach(data.data.items, function(image) {
+        if (isValidSnapshot(image) && enabledSnapshot) {
+          model.imageSnapshots.push(image);
+        } else if (isValidImage(image) && enabledImage) {
+          model.images.push(image);
+        }
+      });
+
+      if (enabledImage) {
+        addAllowedBootSource(
+          model.images, bootSourceTypes.IMAGE, gettext('Image')
+        );
+      }
+
+      if (enabledSnapshot) {
+        addAllowedBootSource(
+          model.imageSnapshots, bootSourceTypes.INSTANCE_SNAPSHOT,
+          gettext('Instance Snapshot')
+        );
+      }
     }
 
     function onGetVolumes(data) {
