@@ -137,8 +137,12 @@
               {container_format: 'ari', properties: {}},
               {container_format: 'ami', properties: {}},
               {container_format: 'raw', properties: {}},
-              {container_format: 'ami', properties: {image_type: 'snapshot'}},
-              {container_format: 'raw', properties: {image_type: 'snapshot'}}
+              {container_format: 'ami', properties: {image_type: 'image'}},
+              {container_format: 'raw', properties: {image_type: 'image'}},
+              {container_format: 'ami', properties: {
+                block_device_mapping: '[{"source_type": "snapshot"}]'}},
+              {container_format: 'raw', properties: {
+                block_device_mapping: '[{"source_type": "snapshot"}]'}}
             ];
 
             var deferred = $q.defer();
@@ -160,6 +164,7 @@
           settings = {
             LAUNCH_INSTANCE_DEFAULTS: {
               create_volume: true,
+              hide_create_volume: false,
               config_drive: false,
               disable_image: false,
               disable_instance_snapshot: false,
@@ -172,47 +177,6 @@
           VOLUME_SNAPSHOT = {type: 'volume_snapshot', label: 'Volume Snapshot'};
           INSTANCE_SNAPSHOT = {type: 'snapshot', label: 'Instance Snapshot'};
         });
-
-        $provide.value('horizon.app.core.openstack-service-api.nova', novaApi);
-      }));
-
-      beforeEach(module('horizon.dashboard.project.workflow.launch-instance'));
-
-      beforeEach(module(function($provide) {
-        $provide.value('horizon.app.core.openstack-service-api.glance', {
-          getImages: function() {
-            var images = [
-              { container_format: 'aki', properties: {} },
-              { container_format: 'ari', properties: {} },
-              { container_format: 'ami', properties: {} },
-              { container_format: 'raw', properties: {} },
-              { container_format: 'ami', properties: { image_type: 'snapshot' } },
-              { container_format: 'raw', properties: { image_type: 'snapshot' } }
-            ];
-
-            var deferred = $q.defer();
-            deferred.resolve({ data: { items: images } });
-
-            return deferred.promise;
-          },
-          getNamespaces: function() {
-            var namespaces = [ 'ns-1', 'ns-2' ];
-
-            var deferred = $q.defer();
-            deferred.resolve({ data: { items: namespaces } });
-
-            return deferred.promise;
-          }
-        });
-
-        beforeEach(function() {
-          settings = {
-            LAUNCH_INSTANCE_DEFAULTS: {
-              config_drive: false
-            }
-          };
-        });
-
         $provide.value('horizon.app.core.openstack-service-api.nova', novaApi);
 
         $provide.value('horizon.app.core.openstack-service-api.security-group', securityGroupApi);
@@ -421,14 +385,50 @@
           expect(model.initialized).toBe(true);
           expect(model.newInstanceSpec).toBeDefined();
 
-          expect(model.images.length).toBe(2);
-          expect(model.imageSnapshots.length).toBe(2);
-          expect(model.availabilityZones.length).toBe(3); // 2 + 1 for 'nova pick'
-          expect(model.flavors.length).toBe(2);
-          expect(model.keypairs.length).toBe(2);
-          expect(model.securityGroups.length).toBe(2);
-          expect(model.novaLimits.maxTotalInstances).toBe(10);
-          expect(model.novaLimits.totalInstancesUsed).toBe(0);
+          var expectedImages = [
+            {container_format: 'ami', properties: {}},
+            {container_format: 'raw', properties: {}},
+            {container_format: 'ami', properties: {image_type: 'image'}},
+            {container_format: 'raw', properties: {image_type: 'image'}}
+          ];
+          expect(model.images).toEqual(expectedImages);
+
+          var expectedSnapshots = [
+            {
+              container_format: 'ami',
+              properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}
+            },
+            {
+              container_format: 'raw',
+              properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}
+            }
+          ];
+          expect(model.imageSnapshots).toEqual(expectedSnapshots);
+
+          var expectedZones = [
+            {'label': 'Any Availability Zone', 'value': ''},
+            {'label': 'zone-1', 'value': 'zone-1'},
+            {'label': 'zone-2', 'value': 'zone-2'}
+          ];
+          expect(model.availabilityZones).toEqual(expectedZones);
+
+          var expectedFlavors = ['flavor-1', 'flavor-2'];
+          expect(model.flavors).toEqual(expectedFlavors);
+
+          var expectedKeypairs = [
+            {'name': 'key-1', id: 'li_keypair:key-1'},
+            {'name': 'key-2', id: 'li_keypair:key-2'}
+          ];
+          expect(model.keypairs).toEqual(expectedKeypairs);
+
+          var expectedSecurityGroups = [
+            {name: 'security-group-1'},
+            {name: 'security-group-2'}
+          ];
+          expect(model.securityGroups).toEqual(expectedSecurityGroups);
+
+          var expectedLimits = {maxTotalInstances: 10, totalInstancesUsed: 0};
+          expect(model.novaLimits).toEqual(expectedLimits);
         });
 
         it('should have networks & no volumes if neutron enabled & cinder disabled', function() {
@@ -512,6 +512,22 @@
           expect(model.newInstanceSpec.create_volume_default).toBe(false);
         });
 
+        it('should default hide_create_volume to false if setting not provided', function() {
+          delete settings.LAUNCH_INSTANCE_DEFAULTS.hide_create_volume;
+          model.initialize(true);
+          scope.$apply();
+
+          expect(model.newInstanceSpec.hide_create_volume).toBe(false);
+        });
+
+        it('should default hide_create_volume to true based on setting', function() {
+          settings.LAUNCH_INSTANCE_DEFAULTS.hide_create_volume = true;
+          model.initialize(true);
+          scope.$apply();
+
+          expect(model.newInstanceSpec.hide_create_volume).toBe(true);
+        });
+
         it('should not set availability zone if the zone list is empty', function () {
           spyOn(novaApi, 'getAvailabilityZones').and.callFake(function () {
             var deferred = $q.defer();
@@ -825,7 +841,7 @@
         // This is here to ensure that as people add/change items, they
         // don't forget to implement tests for them.
         it('has the right number of properties', function() {
-          expect(Object.keys(model.newInstanceSpec).length).toBe(22);
+          expect(Object.keys(model.newInstanceSpec).length).toBe(23);
         });
 
         it('sets availability zone to null', function() {
