@@ -37,7 +37,7 @@ from openstack_dashboard.dashboards.project.volume_groups \
 CGROUP_INFO_FIELDS = ("name",
                       "description")
 
-INDEX_URL = "horizon:project:cgroups:index"
+INDEX_URL = "horizon:project:volume_groups:index"
 
 
 class IndexView(tables.DataTableView):
@@ -203,14 +203,15 @@ class CreateSnapshotView(forms.ModalFormView):
             volumes = api.cinder.volume_list(self.request,
                                              search_opts=search_opts)
             num_volumes = len(volumes)
-            usages = quotas.tenant_limit_usages(self.request)
+            usages = quotas.tenant_quota_usages(
+                self.request, targets=('snapshots', 'gigabytes'))
 
-            if usages['totalSnapshotsUsed'] + num_volumes > \
-                    usages['maxTotalSnapshots']:
+            if (usages['snapshots']['used'] + num_volumes >
+                    usages['snapshots']['quota']):
                 raise ValueError(_('Unable to create snapshots due to '
                                    'exceeding snapshot quota limit.'))
             else:
-                usages['numRequestedItems'] = num_volumes
+                context['numRequestedItems'] = num_volumes
                 context['usages'] = usages
 
         except ValueError as e:
@@ -246,14 +247,15 @@ class CloneGroupView(forms.ModalFormView):
             volumes = api.cinder.volume_list(self.request,
                                              search_opts=search_opts)
             num_volumes = len(volumes)
-            usages = quotas.tenant_limit_usages(self.request)
+            usages = quotas.tenant_quota_usages(
+                self.request, targets=('volumes', 'gigabytes'))
 
-            if usages['totalVolumesUsed'] + num_volumes > \
-                    usages['maxTotalVolumes']:
+            if (usages['volumes']['used'] + num_volumes >
+                    usages['volumes']['quota']):
                 raise ValueError(_('Unable to create group due to '
                                    'exceeding volume quota limit.'))
             else:
-                usages['numRequestedItems'] = num_volumes
+                context['numRequestedItems'] = num_volumes
                 context['usages'] = usages
 
         except ValueError as e:
