@@ -74,7 +74,7 @@ class LaunchVolumeNG(LaunchVolume):
 
     def __init__(self, attrs=None, **kwargs):
         kwargs['preempt'] = True
-        super(LaunchVolume, self).__init__(attrs, **kwargs)
+        super(LaunchVolumeNG, self).__init__(attrs, **kwargs)
 
     def get_link_url(self, datum):
         url = reverse(self.url)
@@ -92,6 +92,7 @@ class LaunchVolumeNG(LaunchVolume):
 class DeleteVolume(VolumePolicyTargetMixin, tables.DeleteAction):
     help_text = _("Deleted volumes are not recoverable. "
                   "All data stored in the volume will be removed.")
+    default_message_level = "info"
 
     @staticmethod
     def action_present(count):
