@@ -19,10 +19,10 @@ Views for managing volumes.
 from collections import OrderedDict
 import json
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
 from django import shortcuts
 from django.template.defaultfilters import slugify
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.decorators import method_decorator
 from django.utils import encoding
 from django.utils.translation import ugettext_lazy as _
@@ -41,6 +41,7 @@ from openstack_dashboard.api import nova
 from openstack_dashboard import exceptions as dashboard_exception
 from openstack_dashboard.usage import quotas
 from openstack_dashboard.utils import filters
+from openstack_dashboard.utils import futurist_utils
 
 from openstack_dashboard.dashboards.project.volumes \
     import forms as volume_forms
@@ -61,19 +62,13 @@ class VolumeTableMixIn(object):
                 cinder.volume_list_paged(self.request, marker=marker,
                                          search_opts=search_opts,
                                          sort_dir=sort_dir, paginate=True)
-
-            if sort_dir == "asc":
-                volumes.reverse()
-
             return volumes
         except Exception:
             exceptions.handle(self.request,
                               _('Unable to retrieve volume list.'))
             return []
 
-    def _get_instances(self, search_opts=None, instance_ids=None):
-        if not instance_ids:
-            return []
+    def _get_instances(self, search_opts=None):
         try:
             # TODO(tsufiev): we should pass attached_instance_ids to
             # nova.server_list as soon as Nova API allows for this
@@ -93,7 +88,7 @@ class VolumeTableMixIn(object):
                 self.request, search_opts=search_opts)
             if snapshots:
                 # extract out the volume ids
-                volume_ids = set([(s.volume_id) for s in snapshots])
+                volume_ids = set(s.volume_id for s in snapshots)
         except Exception:
             exceptions.handle(self.request,
                               _("Unable to retrieve snapshot list."))
@@ -109,6 +104,25 @@ class VolumeTableMixIn(object):
                     attached_instance_ids.append(server_id)
         return attached_instance_ids
 
+    def _get_groups(self, volumes, search_opts=None):
+        needs_group = False
+        if volumes and hasattr(volumes[0], 'group_id'):
+            needs_group = True
+        if needs_group:
+            try:
+                groups_list = cinder.group_list(self.request,
+                                                search_opts=search_opts)
+                groups = dict((g.id, g) for g in groups_list)
+            except Exception:
+                groups = {}
+                exceptions.handle(self.request,
+                                  _("Unable to retrieve volume groups"))
+        for volume in volumes:
+            if needs_group:
+                volume.group = groups.get(volume.group_id)
+            else:
+                volume.group = None
+
     # set attachment string and if volume has snapshots
     def _set_volume_attributes(self,
                                volumes,
@@ -131,12 +145,41 @@ class VolumesView(tables.PagedTableMixin, VolumeTableMixIn,
     page_title = _("Volumes")
 
     def get_data(self):
-        volumes = self._get_volumes()
-        attached_instance_ids = self._get_attached_instance_ids(volumes)
-        instances = self._get_instances(instance_ids=attached_instance_ids)
-        volume_ids_with_snapshots = self._get_volumes_ids_with_snapshots()
+        volumes = []
+        attached_instance_ids = []
+        instances = []
+        volume_ids_with_snapshots = []
+
+        def _task_get_volumes():
+            volumes.extend(self._get_volumes())
+            attached_instance_ids.extend(
+                self._get_attached_instance_ids(volumes))
+
+        def _task_get_instances():
+            # As long as Nova API does not allow passing attached_instance_ids
+            # to nova.server_list, this call can be forged to pass anything
+            # != None
+            instances.extend(self._get_instances())
+
+            # In volumes tab we don't need to know about the assignment
+            # instance-image, therefore fixing it to an empty value
+            for instance in instances:
+                if hasattr(instance, 'image'):
+                    if isinstance(instance.image, dict):
+                        instance.image['name'] = "-"
+
+        def _task_get_volumes_snapshots():
+            volume_ids_with_snapshots.extend(
+                self._get_volumes_ids_with_snapshots())
+
+        futurist_utils.call_functions_parallel(
+            _task_get_volumes,
+            _task_get_instances,
+            _task_get_volumes_snapshots)
+
         self._set_volume_attributes(
             volumes, instances, volume_ids_with_snapshots)
+        self._get_groups(volumes)
         return volumes
 
 
@@ -172,6 +215,10 @@ class DetailView(tabs.TabbedTableView):
             for att in volume.attachments:
                 att['instance'] = nova.server_get(self.request,
                                                   att['server_id'])
+            if getattr(volume, 'group_id', None):
+                volume.group = cinder.group_get(self.request, volume.group_id)
+            else:
+                volume.group = None
         except Exception:
             redirect = self.get_redirect_url()
             exceptions.handle(self.request,
@@ -221,7 +268,8 @@ class CreateView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(CreateView, self).get_context_data(**kwargs)
         try:
-            context['usages'] = quotas.tenant_limit_usages(self.request)
+            context['usages'] = quotas.tenant_quota_usages(
+                self.request, targets=('volumes', 'gigabytes'))
             context['volume_types'] = self._get_volume_types()
         except Exception:
             exceptions.handle(self.request)
@@ -279,9 +327,9 @@ class ExtendView(forms.ModalFormView):
         args = (self.kwargs['volume_id'],)
         context['submit_url'] = reverse(self.submit_url, args=args)
         try:
-            usages = quotas.tenant_limit_usages(self.request)
-            usages['totalGigabytesUsed'] = (usages['totalGigabytesUsed']
-                                            - context['volume'].size)
+            usages = quotas.tenant_quota_usages(self.request,
+                                                targets=('gigabytes',))
+            usages.tally('gigabytes', - context['volume'].size)
             context['usages'] = usages
         except Exception:
             exceptions.handle(self.request)
@@ -316,7 +364,8 @@ class CreateSnapshotView(forms.ModalFormView):
                                               "snapshot from an attached "
                                               "volume can result in a "
                                               "corrupted snapshot."))
-            context['usages'] = quotas.tenant_limit_usages(self.request)
+            context['usages'] = quotas.tenant_quota_usages(
+                self.request, targets=('snapshots', 'gigabytes'))
         except Exception:
             exceptions.handle(self.request,
                               _('Unable to retrieve volume information.'))
