@@ -25,13 +25,15 @@ import warnings
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 
+from horizon.utils.escape import monkeypatch_escape
+
+from openstack_dashboard import enabled
 from openstack_dashboard import exceptions
+from openstack_dashboard.local import enabled as local_enabled
 from openstack_dashboard import theme_settings
 from openstack_dashboard.utils import config
 from openstack_dashboard.utils import settings as settings_utils
 
-from horizon.utils.escape import monkeypatch_escape
-
 monkeypatch_escape()
 
 _LOG = logging.getLogger(__name__)
@@ -40,7 +42,6 @@ warnings.formatwarning = lambda message, category, *args, **kwargs: \
     '%s: %s' % (category.__name__, message)
 
 ROOT_PATH = os.path.dirname(os.path.abspath(__file__))
-BIN_DIR = os.path.abspath(os.path.join(ROOT_PATH, '..', 'bin'))
 
 if ROOT_PATH not in sys.path:
     sys.path.append(ROOT_PATH)
@@ -52,6 +53,7 @@ SITE_BRANDING = 'OpenStack Dashboard'
 WEBROOT = '/'
 LOGIN_URL = None
 LOGOUT_URL = None
+LOGIN_ERROR = None
 LOGIN_REDIRECT_URL = None
 MEDIA_ROOT = None
 MEDIA_URL = None
@@ -72,7 +74,7 @@ HORIZON_CONFIG = {
         'types': ['alert-success', 'alert-info']
     },
     'bug_url': None,
-    'help_url': "http://docs.openstack.org",
+    'help_url': "https://docs.openstack.org/",
     'exceptions': {'recoverable': exceptions.RECOVERABLE,
                    'not_found': exceptions.NOT_FOUND,
                    'unauthorized': exceptions.UNAUTHORIZED},
@@ -107,15 +109,15 @@ OPENSTACK_IMAGE_BACKEND = {
     ]
 }
 
-MIDDLEWARE_CLASSES = (
+MIDDLEWARE = (
     'openstack_auth.middleware.OpenstackAuthMonkeyPatchMiddleware',
+    'debreach.middleware.RandomCommentMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'horizon.middleware.OperationLogMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
-    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
     'horizon.middleware.HorizonMiddleware',
     'horizon.themes.ThemeMiddleware',
     'django.middleware.locale.LocaleMiddleware',
@@ -133,6 +135,7 @@ CACHED_TEMPLATE_LOADERS = [
 ]
 
 ADD_TEMPLATE_LOADERS = []
+ADD_TEMPLATE_DIRS = []
 
 TEMPLATES = [
     {
@@ -184,26 +187,41 @@ INSTALLED_APPS = [
     'django.contrib.staticfiles',
     'django.contrib.humanize',
     'django_pyscss',
+    'debreach',
     'openstack_dashboard.django_pyscss_fix',
     'compressor',
     'horizon',
     'openstack_auth',
 ]
 
-TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
 AUTHENTICATION_BACKENDS = ('openstack_auth.backend.KeystoneBackend',)
 AUTHENTICATION_URLS = ['openstack_auth.urls']
 AUTH_USER_MODEL = 'openstack_auth.User'
 MESSAGE_STORAGE = 'django.contrib.messages.storage.fallback.FallbackStorage'
 
-SESSION_ENGINE = 'django.contrib.sessions.backends.signed_cookies'
+SESSION_ENGINE = 'django.contrib.sessions.backends.cache'
+CACHES = {
+    'default': {
+        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
+        'LOCATION': '127.0.0.1:11211',
+    },
+}
+
 SESSION_COOKIE_HTTPONLY = True
 SESSION_EXPIRE_AT_BROWSER_CLOSE = True
 SESSION_COOKIE_SECURE = False
 
-# SESSION_TIMEOUT is a method to supersede the token timeout with a shorter
-# horizon session timeout (in seconds).  So if your token expires in 60
-# minutes, a value of 1800 will log users out after 30 minutes
+# Control whether the SESSION_TIMEOUT period is refreshed due to activity. If
+# False, SESSION_TIMEOUT acts as a hard limit.
+SESSION_REFRESH = True
+
+# This SESSION_TIMEOUT is a method to supercede the token timeout with a
+# shorter horizon session timeout (in seconds). If SESSION_REFRESH is True (the
+# default) SESSION_TIMEOUT acts like an idle timeout rather than being a hard
+# limit, but will never exceed the token expiry. If your token expires in 60
+# minutes, a value of 1800 will log users out after 30 minutes of inactivity,
+# or 60 minutes with activity. Setting SESSION_REFRESH to False will make
+# SESSION_TIMEOUT act like a hard limit on session times.
 SESSION_TIMEOUT = 3600
 
 # When using cookie-based sessions, log error when the session cookie exceeds
@@ -215,6 +233,11 @@ SESSION_COOKIE_MAX_SIZE = 4093
 #                https://bugs.launchpad.net/horizon/+bug/1349463
 SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
 
+# MEMOIZED_MAX_SIZE_DEFAULT allows setting a global default to help control
+# memory usage when caching. It should at least be 2 x the number of threads
+# with a little bit of extra buffer.
+MEMOIZED_MAX_SIZE_DEFAULT = 25
+
 CSRF_FAILURE_VIEW = 'openstack_dashboard.views.csrf_failure'
 
 LANGUAGES = (
@@ -223,6 +246,7 @@ LANGUAGES = (
     ('en', 'English'),
     ('en-au', 'Australian English'),
     ('en-gb', 'British English'),
+    ('eo', 'Esperanto'),
     ('es', 'Spanish'),
     ('fr', 'French'),
     ('id', 'Indonesian'),
@@ -242,11 +266,6 @@ USE_I18N = True
 USE_L10N = True
 USE_TZ = True
 
-LOCALE_PATHS = [
-    'horizon/locale',
-    'openstack_dashboard/locale',
-]
-
 # Set OPENSTACK_CLOUDS_YAML_NAME to provide a nicer name for this cloud for
 # the clouds.yaml file than "openstack".
 OPENSTACK_CLOUDS_YAML_NAME = 'openstack'
@@ -299,20 +318,9 @@ SECURITY_GROUP_RULES = {
 
 ADD_INSTALLED_APPS = []
 
-USER_MENU_LINKS = [
-    {'name': _('OpenStack RC File v2'),
-     'icon_classes': ['fa-download', ],
-     'url': 'horizon:project:api_access:openrcv2'
-     },
-    {'name': _('OpenStack RC File v3'),
-     'icon_classes': ['fa-download', ],
-     'url': 'horizon:project:api_access:openrc'
-     }
-]
-
-# Deprecated Theme Settings
-CUSTOM_THEME_PATH = None
-DEFAULT_THEME_PATH = None
+# NOTE: The default value of USER_MENU_LINKS will be set after loading
+# local_settings if it is not configured.
+USER_MENU_LINKS = None
 
 # 'key', 'label', 'path'
 AVAILABLE_THEMES = [
@@ -342,7 +350,9 @@ CSRF_COOKIE_AGE = None
 
 COMPRESS_OFFLINE_CONTEXT = 'horizon.themes.offline_context'
 
-SHOW_KEYSTONE_V2_RC = True
+SHOW_KEYSTONE_V2_RC = False
+SHOW_OPENRC_FILE = True
+SHOW_OPENSTACK_CLOUDS_YAML = True
 
 # Dictionary of currently available angular features
 ANGULAR_FEATURES = {
@@ -383,6 +393,8 @@ except ImportError:
 if not TEMPLATES[0]['DIRS']:
     TEMPLATES[0]['DIRS'] = [os.path.join(ROOT_PATH, 'templates')]
 
+TEMPLATES[0]['DIRS'] += ADD_TEMPLATE_DIRS
+
 # configure template debugging
 TEMPLATES[0]['OPTIONS']['debug'] = DEBUG
 
@@ -405,6 +417,7 @@ if os.path.exists(LOCAL_SETTINGS_DIR_PATH):
             if filename.endswith(".py"):
                 try:
                     with open(os.path.join(dirpath, filename)) as f:
+                        # pylint: disable=exec-used
                         exec(f.read())
                 except Exception as e:
                     _LOG.exception(
@@ -416,12 +429,30 @@ if os.path.exists(LOCAL_SETTINGS_DIR_PATH):
 OPENSTACK_IMAGE_FORMATS = [fmt for (fmt, name)
                            in OPENSTACK_IMAGE_BACKEND['image_formats']]
 
+if USER_MENU_LINKS is None:
+    USER_MENU_LINKS = []
+    if SHOW_KEYSTONE_V2_RC:
+        USER_MENU_LINKS.append({
+            'name': _('OpenStack RC File v2'),
+            'icon_classes': ['fa-download', ],
+            'url': 'horizon:project:api_access:openrcv2',
+        })
+    if SHOW_OPENRC_FILE:
+        USER_MENU_LINKS.append({
+            'name': (_('OpenStack RC File v3') if SHOW_KEYSTONE_V2_RC
+                     else _('OpenStack RC File')),
+            'icon_classes': ['fa-download', ],
+            'url': 'horizon:project:api_access:openrc',
+        })
+
 if not WEBROOT.endswith('/'):
     WEBROOT += '/'
 if LOGIN_URL is None:
     LOGIN_URL = WEBROOT + 'auth/login/'
 if LOGOUT_URL is None:
     LOGOUT_URL = WEBROOT + 'auth/logout/'
+if LOGIN_ERROR is None:
+    LOGIN_ERROR = WEBROOT + 'auth/error/'
 if LOGIN_REDIRECT_URL is None:
     LOGIN_REDIRECT_URL = WEBROOT
 
@@ -440,26 +471,13 @@ if STATIC_URL is None:
 AVAILABLE_THEMES, SELECTABLE_THEMES, DEFAULT_THEME = (
     theme_settings.get_available_themes(
         AVAILABLE_THEMES,
-        CUSTOM_THEME_PATH,
-        DEFAULT_THEME_PATH,
         DEFAULT_THEME,
         SELECTABLE_THEMES
     )
 )
 
-if CUSTOM_THEME_PATH is not None:
-    _LOG.warning("CUSTOM_THEME_PATH has been deprecated.  Please convert "
-                 "your settings to make use of AVAILABLE_THEMES.")
-
-if DEFAULT_THEME_PATH is not None:
-    _LOG.warning("DEFAULT_THEME_PATH has been deprecated.  Please convert "
-                 "your settings to make use of AVAILABLE_THEMES.")
-
-# Discover all the directories that contain static files; at the same time
-# discover all the xstatic module entry points to embed in our HTML
-STATICFILES_DIRS = settings_utils.get_xstatic_dirs(
-    XSTATIC_MODULES, HORIZON_CONFIG)
-STATICFILES_DIRS += theme_settings.get_theme_static_dirs(
+# Discover all the directories that contain static files
+STATICFILES_DIRS = theme_settings.get_theme_static_dirs(
     AVAILABLE_THEMES, THEME_COLLECTION_DIR, ROOT_PATH)
 
 # Ensure that we always have a SECRET_KEY set, even when no local_settings.py
@@ -470,6 +488,7 @@ if not SECRET_KEY:
         LOCAL_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                   'local')
 
+    # pylint: disable=ungrouped-imports
     from horizon.utils import secret_key
     SECRET_KEY = secret_key.generate_or_read_from_file(os.path.join(LOCAL_PATH,
                                                        '.secret_key_store'))
@@ -479,16 +498,11 @@ if not SECRET_KEY:
 settings_utils.find_static_files(HORIZON_CONFIG, AVAILABLE_THEMES,
                                  THEME_COLLECTION_DIR, ROOT_PATH)
 
-
-# Load the pluggable dashboard settings
-import openstack_dashboard.enabled
-import openstack_dashboard.local.enabled
-
 INSTALLED_APPS = list(INSTALLED_APPS)  # Make sure it's mutable
 settings_utils.update_dashboards(
     [
-        openstack_dashboard.enabled,
-        openstack_dashboard.local.enabled,
+        enabled,
+        local_enabled,
     ],
     HORIZON_CONFIG,
     INSTALLED_APPS,
@@ -497,6 +511,13 @@ INSTALLED_APPS[0:0] = ADD_INSTALLED_APPS
 
 NG_TEMPLATE_CACHE_AGE = NG_TEMPLATE_CACHE_AGE if not DEBUG else 0
 
+# Include xstatic_modules specified in plugin
+XSTATIC_MODULES += HORIZON_CONFIG['xstatic_modules']
+
+# Discover all the xstatic module entry points to embed in our HTML
+STATICFILES_DIRS += settings_utils.get_xstatic_dirs(
+    XSTATIC_MODULES, HORIZON_CONFIG)
+
 # This base context objects gets added to the offline context generator
 # for each theme configured.
 HORIZON_COMPRESS_OFFLINE_CONTEXT_BASE = {
@@ -513,11 +534,3 @@ if DEBUG:
 # Here comes the Django settings deprecation section. Being at the very end
 # of settings.py allows it to catch the settings defined in local_settings.py
 # or inside one of local_settings.d/ snippets.
-if 'HORIZON_IMAGES_ALLOW_UPLOAD' in globals():
-    message = 'The setting HORIZON_IMAGES_ALLOW_UPLOAD is deprecated in ' \
-              'Newton and will be removed in P release. Use the setting ' \
-              'HORIZON_IMAGES_UPLOAD_MODE instead.'
-    if not HORIZON_IMAGES_ALLOW_UPLOAD:
-        message += ' Keep in mind that HORIZON_IMAGES_ALLOW_UPLOAD set to ' \
-                   'False overrides the value of HORIZON_IMAGES_UPLOAD_MODE.'
-    _LOG.warning(message)
