@@ -48,6 +48,7 @@
       .setNames(gettext('Key Pair'), gettext('Key Pairs'))
       // for detail summary view on table row.
       .setSummaryTemplateUrl(basePath + 'details/drawer.html')
+      .setDefaultIndexUrl('/project/key_pairs/')
       .setProperties(keypairProperties())
       .setListFunction(keypairsService.getKeypairsPromise)
       .tableColumns
@@ -55,11 +56,16 @@
         id: 'name',
         priority: 1,
         sortDefault: true,
+        classes: "word-wrap",
         urlFunction: keypairsService.urlFunction
       })
       .append({
-        id: 'fingerprint',
+        id: 'type',
         priority: 2
+      })
+      .append({
+        id: 'fingerprint',
+        priority: 3
       });
 
     // for magic-search
@@ -76,6 +82,7 @@
       'id': {},
       'keypair_id': {label: gettext('ID'), filters: ['noValue'] },
       'name': {label: gettext('Name'), filters: ['noName'] },
+      'type': {label: gettext('Type'), filters: ['noValue']},
       'fingerprint': {label: gettext('Fingerprint'), filters: ['noValue'] },
       'created_at': {label: gettext('Created'), filters: ['mediumDate'] },
       'user_id': {label: gettext('User ID'), filters: ['noValue'] },
