@@ -15,6 +15,7 @@
 from cinderclient.v2 import availability_zones
 from cinderclient.v2 import cgsnapshots
 from cinderclient.v2 import consistencygroups
+from cinderclient.v2.contrib import list_extensions as cinder_list_extensions
 from cinderclient.v2 import pools
 from cinderclient.v2 import qos_specs
 from cinderclient.v2 import quotas
@@ -26,11 +27,14 @@ from cinderclient.v2 import volume_transfers
 from cinderclient.v2 import volume_type_access
 from cinderclient.v2 import volume_types
 from cinderclient.v2 import volumes
+from cinderclient.v3 import group_snapshots
+from cinderclient.v3 import group_types
+from cinderclient.v3 import groups
 
 from openstack_dashboard import api
-from openstack_dashboard.usage import quotas as usage_quotas
-
+from openstack_dashboard.api import cinder as cinder_api
 from openstack_dashboard.test.test_data import utils
+from openstack_dashboard.usage import quotas as usage_quotas
 
 
 def data(TEST):
@@ -45,6 +49,7 @@ def data(TEST):
     TEST.cinder_qos_specs = utils.TestDataContainer()
     TEST.cinder_qos_spec_associations = utils.TestDataContainer()
     TEST.cinder_volume_snapshots = utils.TestDataContainer()
+    TEST.cinder_extensions = utils.TestDataContainer()
     TEST.cinder_quotas = utils.TestDataContainer()
     TEST.cinder_quota_usages = utils.TestDataContainer()
     TEST.cinder_availability_zones = utils.TestDataContainer()
@@ -53,6 +58,11 @@ def data(TEST):
     TEST.cinder_consistencygroups = utils.TestDataContainer()
     TEST.cinder_cgroup_volumes = utils.TestDataContainer()
     TEST.cinder_cg_snapshots = utils.TestDataContainer()
+    TEST.cinder_groups = utils.TestDataContainer()
+    TEST.cinder_group_types = utils.TestDataContainer()
+    TEST.cinder_group_snapshots = utils.TestDataContainer()
+    TEST.cinder_group_volumes = utils.TestDataContainer()
+    TEST.cinder_volume_snapshots_with_groups = utils.TestDataContainer()
 
     # Services
     service_1 = services.Service(services.ServiceManager(None), {
@@ -85,7 +95,7 @@ def data(TEST):
         {'id': "11023e92-8008-4c8b-8059-7f2293ff3887",
          'status': 'available',
          'size': 40,
-         'display_name': 'Volume name',
+         'name': 'Volume name',
          'display_description': 'Volume description',
          'created_at': '2014-01-27 10:30:00',
          'volume_type': None,
@@ -95,7 +105,7 @@ def data(TEST):
         {"id": "4b069dd0-6eaa-4272-8abc-5448a68f1cce",
          "status": 'available',
          "size": 10,
-         "display_name": '',
+         "name": '',
          "display_description": '',
          "device": "/dev/hda",
          "created_at": '2010-11-21 18:34:25',
@@ -106,7 +116,7 @@ def data(TEST):
         {'id': "21023e92-8008-1234-8059-7f2293ff3889",
          'status': 'in-use',
          'size': 10,
-         'display_name': u'my_volume',
+         'name': u'my_volume',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
@@ -118,7 +128,7 @@ def data(TEST):
          'name': 'my_volume2',
          'status': 'in-use',
          'size': 10,
-         'display_name': u'my_volume2',
+         'name': u'my_volume2',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': 'vol_type_2',
@@ -129,7 +139,7 @@ def data(TEST):
         {'id': "21023e92-8008-1234-8059-7f2293ff3890",
          'status': 'in-use',
          'size': 10,
-         'display_name': u'my_volume',
+         'name': u'my_volume',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
@@ -148,22 +158,24 @@ def data(TEST):
 
     TEST.cinder_bootable_volumes.add(api.cinder.Volume(non_bootable_volume))
 
-    vol_type1 = volume_types.VolumeType(volume_types.VolumeTypeManager(None),
-                                        {'id': u'1',
-                                         'name': u'vol_type_1',
-                                         'description': 'type 1 description',
-                                         'extra_specs': {'foo': 'bar',
-                                                         'volume_backend_name':
-                                                         'backend_1'}})
-    vol_type2 = volume_types.VolumeType(volume_types.VolumeTypeManager(None),
-                                        {'id': u'2',
-                                         'name': u'vol_type_2',
-                                         'description': 'type 2 description'})
-    vol_type3 = volume_types.VolumeType(volume_types.VolumeTypeManager(None),
-                                        {'id': u'3',
-                                         'name': u'vol_type_3',
-                                         'is_public': False,
-                                         'description': 'type 3 description'})
+    vol_type1 = volume_types.VolumeType(
+        volume_types.VolumeTypeManager(None),
+        {'id': u'1',
+         'name': u'vol_type_1',
+         'description': 'type 1 description',
+         'extra_specs': {'foo': 'bar',
+                         'volume_backend_name': 'backend_1'}})
+    vol_type2 = volume_types.VolumeType(
+        volume_types.VolumeTypeManager(None),
+        {'id': u'2',
+         'name': u'vol_type_2',
+         'description': 'type 2 description'})
+    vol_type3 = volume_types.VolumeType(
+        volume_types.VolumeTypeManager(None),
+        {'id': u'3',
+         'name': u'vol_type_3',
+         'is_public': False,
+         'description': 'type 3 description'})
     TEST.cinder_volume_types.add(vol_type1, vol_type2, vol_type3)
     vol_type_access1 = volume_type_access.VolumeTypeAccess(
         volume_type_access.VolumeTypeAccessManager(None),
@@ -297,6 +309,32 @@ def data(TEST):
     TEST.cinder_volume_encryption.add(vol_enc_metadata1)
     TEST.cinder_volume_encryption.add(vol_unenc_metadata1)
 
+    # v2 extensions
+
+    extensions = [
+        {'alias': 'os-services',
+         'description': 'Services support.',
+         'links': '[]',
+         'name': 'Services',
+         'updated': '2012-10-28T00:00:00-00:00'},
+        {'alias': 'os-admin-actions',
+         'description': 'Enable admin actions.',
+         'links': '[]',
+         'name': 'AdminActions',
+         'updated': '2012-08-25T00:00:00+00:00'},
+        {'alias': 'os-volume-transfer',
+         'description': 'Volume transfer management support.',
+         'links': '[]',
+         'name': 'VolumeTransfer',
+         'updated': '2013-05-29T00:00:00+00:00'},
+    ]
+    extensions = [
+        cinder_list_extensions.ListExtResource(
+            cinder_list_extensions.ListExtManager(None), ext)
+        for ext in extensions
+    ]
+    TEST.cinder_extensions.add(*extensions)
+
     # Quota Sets
     quota_data = dict(volumes='1',
                       snapshots='1',
@@ -307,8 +345,8 @@ def data(TEST):
     # Quota Usages
     quota_usage_data = {'gigabytes': {'used': 0,
                                       'quota': 1000},
-                        'instances': {'used': 0,
-                                      'quota': 10},
+                        'volumes': {'used': 0,
+                                    'quota': 10},
                         'snapshots': {'used': 0,
                                       'quota': 10}}
     quota_usage = usage_quotas.QuotaUsage()
@@ -424,7 +462,7 @@ def data(TEST):
         {'id': u'1',
          'name': u'cg_1',
          'description': 'cg 1 description',
-         'volume_types': u'1',
+         'volume_types': ['1'],
          'volume_type_names': []})
 
     cgroup_2 = consistencygroups.Consistencygroup(
@@ -432,7 +470,7 @@ def data(TEST):
         {'id': u'2',
          'name': u'cg_2',
          'description': 'cg 2 description',
-         'volume_types': u'1',
+         'volume_types': ['1'],
          'volume_type_names': []})
 
     TEST.cinder_consistencygroups.add(cgroup_1)
@@ -443,10 +481,10 @@ def data(TEST):
         {'id': "11023e92-8008-4c8b-8059-7f2293ff3881",
          'status': 'available',
          'size': 40,
-         'display_name': 'Volume name',
+         'name': 'Volume name',
          'display_description': 'Volume description',
          'created_at': '2014-01-27 10:30:00',
-         'volume_type': None,
+         'volume_type': 'vol_type_1',
          'attachments': [],
          'consistencygroup_id': u'1'})
     TEST.cinder_cgroup_volumes.add(api.cinder.Volume(
@@ -460,3 +498,86 @@ def data(TEST):
          'description': 'cg_ss 1 description',
          'consistencygroup_id': u'1'})
     TEST.cinder_cg_snapshots.add(cg_snapshot_1)
+
+    group_type_1 = group_types.GroupType(
+        group_types.GroupTypeManager(None),
+        {
+            "is_public": True,
+            "group_specs": {},
+            "id": "4645cbf7-8aa6-4d42-a5f7-24e6ebe5ba79",
+            "name": "group-type-1",
+            "description": None,
+        })
+    TEST.cinder_group_types.add(group_type_1)
+
+    group_1 = groups.Group(
+        groups.GroupManager(None),
+        {
+            "availability_zone": "nova",
+            "created_at": "2018-01-09T07:27:22.000000",
+            "description": "description for group1",
+            "group_snapshot_id": None,
+            "group_type": group_type_1.id,
+            "id": "f64646ac-9bf7-483f-bd85-96c34050a528",
+            "name": "group1",
+            "replication_status": "disabled",
+            "source_group_id": None,
+            "status": "available",
+            "volume_types": [
+                vol_type1.id,
+            ]
+        })
+    TEST.cinder_groups.add(cinder_api.Group(group_1))
+
+    group_snapshot_1 = group_snapshots.GroupSnapshot(
+        group_snapshots.GroupSnapshotManager(None),
+        {
+            "created_at": "2018-01-09T07:46:03.000000",
+            "description": "",
+            "group_id": group_1.id,
+            "group_type_id": group_type_1.id,
+            "id": "1036d913-9cb8-46a1-9f56-2f99dc1f14ed",
+            "name": "group-snap1",
+            "status": "available",
+        })
+    TEST.cinder_group_snapshots.add(group_snapshot_1)
+
+    group_volume_1 = volumes.Volume(
+        volumes.VolumeManager(None),
+        {'id': "fe9a2664-0f49-4354-bab6-11b2ad352630",
+         'status': 'available',
+         'size': 2,
+         'name': 'group1-volume1',
+         'display_description': 'Volume 1 in Group 1',
+         'created_at': '2014-01-27 10:30:00',
+         'volume_type': 'vol_type_1',
+         'group_id': group_1.id,
+         'attachments': []})
+
+    group_volume_2 = volumes.Volume(
+        volumes.VolumeManager(None),
+        {'id': "a7fb0402-88dc-45a3-970c-d732da63466e",
+         'status': 'available',
+         'size': 1,
+         'name': 'group1-volume2',
+         'display_description': 'Volume 2 in Group 1',
+         'created_at': '2014-01-30 10:31:00',
+         'volume_type': 'vol_type_1',
+         'group_id': group_1.id,
+         'attachments': []})
+    TEST.cinder_group_volumes.add(group_volume_1)
+    TEST.cinder_group_volumes.add(group_volume_2)
+
+    snapshot5 = vol_snaps.Snapshot(
+        vol_snaps.SnapshotManager(None),
+        {'id': 'cd6be1eb-82ca-4587-8036-13c37c00c2b1',
+         'name': '',
+         'description': 'v2 volume snapshot with metadata description',
+         'size': 80,
+         'status': 'available',
+         'volume_id': '7e4efa56-9ca1-45ff-b83c-2efb2383930d',
+         'metadata': {'snapshot_meta_key': 'snapshot_meta_value'},
+         'group_snapshot_id': group_snapshot_1.id})
+
+    TEST.cinder_volume_snapshots_with_groups.add(
+        api.cinder.VolumeSnapshot(snapshot5))
