@@ -16,16 +16,16 @@ from importlib import import_module
 import logging
 
 from django.conf import settings
-from django.core import urlresolvers
 from django import http
 from django import shortcuts
+from django import urls
+from django.utils.encoding import smart_text
 from django.utils.translation import ugettext as _
 import django.views.decorators.vary
 from django.views.generic import TemplateView
 from six.moves import urllib
 
 import horizon
-from horizon import base
 from horizon import exceptions
 from horizon import notifications
 
@@ -36,27 +36,13 @@ MESSAGES_PATH = getattr(settings, 'MESSAGES_PATH', None)
 
 
 def get_user_home(user):
-    try:
-        token = user.token
-    except AttributeError:
-        raise exceptions.NotAuthenticated()
-    # Domain Admin, Project Admin will default to identity
-    dashboard = None
-    if token.project.get('id') is None or user.is_superuser:
-        try:
-            dashboard = horizon.get_dashboard('identity')
-        except base.NotRegistered:
-            pass
-
-    if dashboard is None:
-        dashboard = horizon.get_default_dashboard()
-
+    dashboard = horizon.get_default_dashboard()
     return dashboard.get_absolute_url()
 
 
 @django.views.decorators.vary.vary_on_cookie
 def splash(request):
-    if not request.user.is_authenticated():
+    if not request.user.is_authenticated:
         raise exceptions.NotAuthenticated()
 
     response = shortcuts.redirect(horizon.get_user_home(request.user))
@@ -74,9 +60,9 @@ def splash(request):
 def get_url_with_pagination(request, marker_name, prev_marker_name, url_string,
                             object_id=None):
     if object_id:
-        url = urlresolvers.reverse(url_string, args=(object_id,))
+        url = urls.reverse(url_string, args=(object_id,))
     else:
-        url = urlresolvers.reverse(url_string)
+        url = urls.reverse(url_string)
     marker = request.GET.get(marker_name, None)
     if marker:
         return "{}?{}".format(url,
@@ -110,7 +96,7 @@ class ExtensibleHeaderView(TemplateView):
                 response = view.get(self.request)
                 rendered_response = response.render()
                 packed_response = [view_path.replace('.', '-'),
-                                   rendered_response.content]
+                                   smart_text(rendered_response.content)]
                 header_sections.append(packed_response)
 
             except Exception as e:
